Struct ostree::Repo

source ·
#[repr(transparent)]
pub struct Repo { /* private fields */ }

Implementations

Available on crate feature v2016_8 only.
Available on crate feature v2017_12 only.
Available on crate feature v2017_15 only.
Available on crate feature v2019_2 only.
Available on crate feature v2018_6 only.
Available on crate feature v2018_9 only.
Available on crate feature v2016_4 only.
Available on crate feature v2018_9 only.
Available on crate feature v2016_5 only.
Available on crate feature v2016_5 only.
Available on crate feature v2016_5 only.
Available on crate feature v2020_8 only.
Available on crate feature v2016_6 only.
Available on crate feature v2017_12 only.
Available on crate feature v2016_5 only.
Available on crate feature v2020_8 only.
Available on crate feature v2015_7 only.
Available on crate feature v2017_15 only.
Available on crate feature v2019_4 only.
Available on crate feature v2017_2 only.
Available on crate feature v2016_6 only.
Available on crate feature v2021_4 only.
Available on crate feature v2018_6 only.
Available on crate feature v2018_6 only.
Available on crate feature v2016_7 only.
Available on crate feature v2017_10 only.
Available on crate feature v2016_5 only.
Available on crate feature v2018_6 only.
Available on crate feature v2018_6 only.
Available on crate feature v2021_4 only.
Available on crate feature v2020_7 only.
Available on crate feature v2020_7 only.
Available on crate feature v2018_6 only.
Available on crate feature v2016_14 only.
Available on crate feature v2021_2 only.
Available on crate feature v2021_2 only.
Available on crate feature v2021_2 only.
Available on crate feature v2017_10 only.
Available on crate feature v2017_10 only.

Create a new Repo object for working with an OSTree repo at the given path.

A wrapper for [prepare_transaction] which ensures the transaction will be aborted when the guard goes out of scope.

Available on crate feature v2016_4 only.

Return a copy of the directory file descriptor for this repository.

Find all objects reachable from a commit.

List all branch names (refs).

List all repo objects

List refs with extended options.

Resolve a refspec to a commit SHA256. Returns an error if the refspec does not exist.

Load the contents (for regular files) and metadata for a content object.

Query metadata for a content object.

This is similar to [load_file], but is more efficient if reading the file content is not needed.

Write a content object from provided input.

Write a metadata object.

Asynchronously write a content object.

Asynchronously write a content object.

Asynchronously write a metadata object.

Asynchronously write a metadata object.

Load and parse directory metadata. In particular, uid/gid/mode are stored in big-endian format; this function converts them to host native endianness.

List all commit objects; an optional prefix filter may be applied.