pub struct RepoCheckoutFilter(_);
A filter callback to decide which files to checkout from a Repo. The function is called for every directory and file in the dirtree.

Arguments

  • repo - the Repo that is being checked out
  • path - the path of the current file, as an absolute path rooted at the commit’s root. The root directory is ‘/’, a subdir would be ‘/subdir’ etc.
  • stat - the metadata of the current file

Return Value

The return value determines whether the current file is checked out or skipped.

Implementations

Wrap a closure for use as a filter function.

Return Value

The return value is always Some containing the value. It simply comes pre-wrapped for your convenience.