#[repr(transparent)]pub struct Repo { /* private fields */ }Implementations
sourceimpl Repo
impl Repo
pub fn new(path: &impl IsA<File>) -> Repo
pub fn new_default() -> Repo
pub fn for_sysroot_path(
repo_path: &impl IsA<File>,
sysroot_path: &impl IsA<File>
) -> Repo
pub fn abort_transaction(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn add_gpg_signature_summary(
&self,
key_id: &[&str],
homedir: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn append_gpg_signature(
&self,
commit_checksum: &str,
signature_bytes: &Bytes,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn checkout_at(
&self,
options: Option<&RepoCheckoutAtOptions>,
destination_dfd: i32,
destination_path: impl AsRef<Path>,
commit: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2016_8 only.pub fn checkout_gc(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn checkout_tree(
&self,
mode: RepoCheckoutMode,
overwrite_mode: RepoCheckoutOverwriteMode,
destination: &impl IsA<File>,
source: &RepoFile,
source_info: &FileInfo,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn commit_transaction(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<RepoTransactionStats, Error>
pub fn copy_config(&self) -> Option<KeyFile>
pub fn create(
&self,
mode: RepoMode,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn delete_object(
&self,
objtype: ObjectType,
sha256: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn equal(&self, b: &Repo) -> bool
v2017_12 only.pub fn fsck_object(
&self,
objtype: ObjectType,
sha256: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2017_15 only.pub fn bootloader(&self) -> Option<GString>
v2019_2 only.pub fn collection_id(&self) -> Option<GString>
v2018_6 only.pub fn config(&self) -> Option<KeyFile>
pub fn default_repo_finders(&self) -> Vec<GString>
v2018_9 only.pub fn dfd(&self) -> i32
v2016_4 only.pub fn is_disable_fsync(&self) -> bool
pub fn min_free_space_bytes(&self) -> Result<u64, Error>
v2018_9 only.pub fn mode(&self) -> RepoMode
pub fn parent(&self) -> Option<Repo>
pub fn path(&self) -> Option<File>
pub fn remote_boolean_option(
&self,
remote_name: &str,
option_name: &str,
default_value: bool
) -> Result<bool, Error>
v2016_5 only.pub fn remote_list_option(
&self,
remote_name: &str,
option_name: &str
) -> Result<Vec<GString>, Error>
v2016_5 only.pub fn remote_option(
&self,
remote_name: &str,
option_name: &str,
default_value: Option<&str>
) -> Result<GString, Error>
v2016_5 only.pub fn gpg_sign_data(
&self,
data: &Bytes,
old_signatures: &Bytes,
key_id: &[&str],
homedir: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Bytes, Error>
v2020_8 only.pub fn gpg_verify_data(
&self,
remote_name: Option<&str>,
data: &Bytes,
signatures: &Bytes,
keyringdir: Option<&impl IsA<File>>,
extra_keyring: Option<&impl IsA<File>>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GpgVerifyResult, Error>
v2016_6 only.pub fn has_object(
&self,
objtype: ObjectType,
checksum: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<bool, Error>
pub fn hash(&self) -> u32
v2017_12 only.pub fn import_object_from(
&self,
source: &Repo,
objtype: ObjectType,
checksum: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn import_object_from_with_trust(
&self,
source: &Repo,
objtype: ObjectType,
checksum: &str,
trusted: bool,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2016_5 only.pub fn is_system(&self) -> bool
pub fn is_writable(&self) -> Result<(), Error>
pub fn list_static_delta_indexes(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Vec<GString>, Error>
v2020_8 only.pub fn list_static_delta_names(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Vec<GString>, Error>
pub fn load_commit(
&self,
checksum: &str
) -> Result<(Variant, RepoCommitState), Error>
v2015_7 only.pub fn load_object_stream(
&self,
objtype: ObjectType,
checksum: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(InputStream, u64), Error>
pub fn load_variant(
&self,
objtype: ObjectType,
sha256: &str
) -> Result<Variant, Error>
pub fn load_variant_if_exists(
&self,
objtype: ObjectType,
sha256: &str
) -> Result<Option<Variant>, Error>
pub fn mark_commit_partial(
&self,
checksum: &str,
is_partial: bool
) -> Result<(), Error>
v2017_15 only.pub fn mark_commit_partial_reason(
&self,
checksum: &str,
is_partial: bool,
in_state: RepoCommitState
) -> Result<(), Error>
v2019_4 only.pub fn open(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn prepare_transaction(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<bool, Error>
pub fn prune(
&self,
flags: RepoPruneFlags,
depth: i32,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(i32, i32, u64), Error>
pub fn prune_static_deltas(
&self,
commit: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn pull(
&self,
remote_name: &str,
refs_to_fetch: &[&str],
flags: RepoPullFlags,
progress: Option<&AsyncProgress>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn pull_one_dir(
&self,
remote_name: &str,
dir_to_pull: &str,
refs_to_fetch: &[&str],
flags: RepoPullFlags,
progress: Option<&AsyncProgress>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn pull_with_options(
&self,
remote_name_or_baseurl: &str,
options: &Variant,
progress: Option<&AsyncProgress>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn query_object_storage_size(
&self,
objtype: ObjectType,
sha256: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<u64, Error>
pub fn read_commit(
&self,
ref_: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(File, GString), Error>
pub fn read_commit_detached_metadata(
&self,
checksum: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Option<Variant>, Error>
pub fn regenerate_summary(
&self,
additional_metadata: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn reload_config(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2017_2 only.pub fn remote_add(
&self,
name: &str,
url: Option<&str>,
options: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn remote_change(
&self,
sysroot: Option<&impl IsA<File>>,
changeop: RepoRemoteChange,
name: &str,
url: Option<&str>,
options: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn remote_delete(
&self,
name: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn remote_fetch_summary(
&self,
name: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(Bytes, Bytes), Error>
pub fn remote_fetch_summary_with_options(
&self,
name: &str,
options: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(Bytes, Bytes), Error>
v2016_6 only.pub fn remote_get_gpg_keys(
&self,
name: Option<&str>,
key_ids: &[&str],
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Vec<Variant>, Error>
v2021_4 only.pub fn remote_get_gpg_verify(&self, name: &str) -> Result<bool, Error>
pub fn remote_get_gpg_verify_summary(&self, name: &str) -> Result<bool, Error>
pub fn remote_get_url(&self, name: &str) -> Result<GString, Error>
pub fn remote_gpg_import(
&self,
name: &str,
source_stream: Option<&impl IsA<InputStream>>,
key_ids: &[&str],
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<u32, Error>
pub fn remote_list(&self) -> Vec<GString>
pub fn resolve_collection_ref(
&self,
ref_: &CollectionRef,
allow_noent: bool,
flags: RepoResolveRevExtFlags,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Option<GString>, Error>
v2018_6 only.pub fn resolve_keyring_for_collection(
&self,
collection_id: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Remote, Error>
v2018_6 only.pub fn resolve_rev(
&self,
refspec: &str,
allow_noent: bool
) -> Result<Option<GString>, Error>
pub fn resolve_rev_ext(
&self,
refspec: &str,
allow_noent: bool,
flags: RepoResolveRevExtFlags
) -> Result<Option<GString>, Error>
v2016_7 only.pub fn scan_hardlinks(
&self,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn set_alias_ref_immediate(
&self,
remote: Option<&str>,
ref_: &str,
target: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2017_10 only.pub fn set_cache_dir(
&self,
dfd: i32,
path: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2016_5 only.pub fn set_collection_id(&self, collection_id: Option<&str>) -> Result<(), Error>
v2018_6 only.pub fn set_collection_ref_immediate(
&self,
ref_: &CollectionRef,
checksum: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2018_6 only.pub fn set_disable_fsync(&self, disable_fsync: bool)
pub fn set_ref_immediate(
&self,
remote: Option<&str>,
ref_: &str,
checksum: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn sign_commit(
&self,
commit_checksum: &str,
key_id: &str,
homedir: Option<&str>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn sign_delta(
&self,
from_commit: &str,
to_commit: &str,
key_id: &str,
homedir: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn signature_verify_commit_data(
&self,
remote_name: &str,
commit_data: &Bytes,
commit_metadata: &Bytes,
flags: RepoVerifyFlags
) -> Result<Option<GString>, Error>
v2021_4 only.pub fn static_delta_execute_offline(
&self,
dir_or_file: &impl IsA<File>,
skip_validation: bool,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn static_delta_execute_offline_with_signature(
&self,
dir_or_file: &impl IsA<File>,
sign: &impl IsA<Sign>,
skip_validation: bool,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
v2020_7 only.pub fn static_delta_generate(
&self,
opt: StaticDeltaGenerateOpt,
from: Option<&str>,
to: &str,
metadata: Option<&Variant>,
params: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn static_delta_verify_signature(
&self,
delta_id: &str,
sign: &impl IsA<Sign>
) -> Result<Option<GString>, Error>
v2020_7 only.pub fn transaction_set_collection_ref(
&self,
ref_: &CollectionRef,
checksum: Option<&str>
)
v2018_6 only.pub fn transaction_set_ref(
&self,
remote: Option<&str>,
ref_: &str,
checksum: Option<&str>
)
pub fn transaction_set_refspec(&self, refspec: &str, checksum: Option<&str>)
pub fn verify_commit(
&self,
commit_checksum: &str,
keyringdir: Option<&impl IsA<File>>,
extra_keyring: Option<&impl IsA<File>>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn verify_commit_ext(
&self,
commit_checksum: &str,
keyringdir: Option<&impl IsA<File>>,
extra_keyring: Option<&impl IsA<File>>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GpgVerifyResult, Error>
pub fn verify_commit_for_remote(
&self,
commit_checksum: &str,
remote_name: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GpgVerifyResult, Error>
v2016_14 only.pub fn verify_summary(
&self,
remote_name: &str,
summary: &Bytes,
signatures: &Bytes,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GpgVerifyResult, Error>
pub fn write_archive_to_mtree(
&self,
archive: &impl IsA<File>,
mtree: &MutableTree,
modifier: Option<&RepoCommitModifier>,
autocreate_parents: bool,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_archive_to_mtree_from_fd(
&self,
fd: i32,
mtree: &MutableTree,
modifier: Option<&RepoCommitModifier>,
autocreate_parents: bool,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_commit(
&self,
parent: Option<&str>,
subject: Option<&str>,
body: Option<&str>,
metadata: Option<&Variant>,
root: &RepoFile,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GString, Error>
pub fn write_commit_detached_metadata(
&self,
checksum: &str,
metadata: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_commit_with_time(
&self,
parent: Option<&str>,
subject: Option<&str>,
body: Option<&str>,
metadata: Option<&Variant>,
root: &RepoFile,
time: u64,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GString, Error>
pub fn write_config(&self, new_config: &KeyFile) -> Result<(), Error>
pub fn write_content_trusted(
&self,
checksum: &str,
object_input: &impl IsA<InputStream>,
length: u64,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_dfd_to_mtree(
&self,
dfd: i32,
path: &str,
mtree: &MutableTree,
modifier: Option<&RepoCommitModifier>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_directory_to_mtree(
&self,
dir: &impl IsA<File>,
mtree: &MutableTree,
modifier: Option<&RepoCommitModifier>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_metadata_stream_trusted(
&self,
objtype: ObjectType,
checksum: &str,
object_input: &impl IsA<InputStream>,
length: u64,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_metadata_trusted(
&self,
objtype: ObjectType,
checksum: &str,
variant: &Variant,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<(), Error>
pub fn write_mtree(
&self,
mtree: &MutableTree,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<File, Error>
pub fn write_regfile(
&self,
expected_checksum: Option<&str>,
uid: u32,
gid: u32,
mode: u32,
content_len: u64,
xattrs: Option<&Variant>
) -> Result<ContentWriter, Error>
v2021_2 only.pub fn write_regfile_inline(
&self,
expected_checksum: Option<&str>,
uid: u32,
gid: u32,
mode: u32,
xattrs: Option<&Variant>,
buf: &[u8],
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GString, Error>
v2021_2 only.pub fn write_symlink(
&self,
expected_checksum: Option<&str>,
uid: u32,
gid: u32,
xattrs: Option<&Variant>,
symlink_target: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<GString, Error>
v2021_2 only.pub fn remotes_config_dir(&self) -> Option<GString>
pub fn sysroot_path(&self) -> Option<File>
pub fn create_at(
dfd: i32,
path: &str,
mode: RepoMode,
options: Option<&Variant>,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Repo, Error>
v2017_10 only.pub fn mode_from_string(mode: &str) -> Result<RepoMode, Error>
pub fn open_at(
dfd: i32,
path: &str,
cancellable: Option<&impl IsA<Cancellable>>
) -> Result<Repo, Error>
v2017_10 only.pub fn connect_gpg_verify_result<F: Fn(&Self, &str, &GpgVerifyResult) + Send + 'static>(
&self,
f: F
) -> SignalHandlerId
sourceimpl Repo
impl Repo
sourcepub fn new_for_path<P: AsRef<Path>>(path: P) -> Repo
pub fn new_for_path<P: AsRef<Path>>(path: P) -> Repo
Create a new Repo object for working with an OSTree repo at the given path.
sourcepub fn auto_transaction<P: IsA<Cancellable>>(
&self,
cancellable: Option<&P>
) -> Result<TransactionGuard<'_>, Error>
pub fn auto_transaction<P: IsA<Cancellable>>(
&self,
cancellable: Option<&P>
) -> Result<TransactionGuard<'_>, Error>
A wrapper for [prepare_transaction] which ensures the transaction will be aborted when the guard goes out of scope.
sourcepub fn dfd_as_file(&self) -> Result<File>
Available on crate feature v2016_4 only.
pub fn dfd_as_file(&self) -> Result<File>
v2016_4 only.Return a copy of the directory file descriptor for this repository.
sourcepub fn traverse_commit<P: IsA<Cancellable>>(
&self,
commit_checksum: &str,
maxdepth: i32,
cancellable: Option<&P>
) -> Result<HashSet<ObjectName>, Error>
pub fn traverse_commit<P: IsA<Cancellable>>(
&self,
commit_checksum: &str,
maxdepth: i32,
cancellable: Option<&P>
) -> Result<HashSet<ObjectName>, Error>
Find all objects reachable from a commit.
sourcepub fn list_refs<P: IsA<Cancellable>>(
&self,
refspec_prefix: Option<&str>,
cancellable: Option<&P>
) -> Result<HashMap<String, String>, Error>
pub fn list_refs<P: IsA<Cancellable>>(
&self,
refspec_prefix: Option<&str>,
cancellable: Option<&P>
) -> Result<HashMap<String, String>, Error>
List all branch names (refs).
sourcepub fn list_objects<P: IsA<Cancellable>>(
&self,
flags: OstreeRepoListObjectsFlags,
cancellable: Option<&P>
) -> Result<HashMap<ObjectName, ObjectDetails>, Error>
pub fn list_objects<P: IsA<Cancellable>>(
&self,
flags: OstreeRepoListObjectsFlags,
cancellable: Option<&P>
) -> Result<HashMap<ObjectName, ObjectDetails>, Error>
List all repo objects
sourcepub fn list_refs_ext<P: IsA<Cancellable>>(
&self,
refspec_prefix: Option<&str>,
flags: RepoListRefsExtFlags,
cancellable: Option<&P>
) -> Result<HashMap<String, String>, Error>
pub fn list_refs_ext<P: IsA<Cancellable>>(
&self,
refspec_prefix: Option<&str>,
flags: RepoListRefsExtFlags,
cancellable: Option<&P>
) -> Result<HashMap<String, String>, Error>
List refs with extended options.
sourcepub fn require_rev(&self, refspec: &str) -> Result<GString, Error>
pub fn require_rev(&self, refspec: &str) -> Result<GString, Error>
Resolve a refspec to a commit SHA256. Returns an error if the refspec does not exist.
sourcepub fn load_file<P: IsA<Cancellable>>(
&self,
checksum: &str,
cancellable: Option<&P>
) -> Result<(Option<InputStream>, FileInfo, Variant), Error>
pub fn load_file<P: IsA<Cancellable>>(
&self,
checksum: &str,
cancellable: Option<&P>
) -> Result<(Option<InputStream>, FileInfo, Variant), Error>
Load the contents (for regular files) and metadata for a content object.
sourcepub fn query_file<P: IsA<Cancellable>>(
&self,
checksum: &str,
cancellable: Option<&P>
) -> Result<(FileInfo, Variant), Error>
pub fn query_file<P: IsA<Cancellable>>(
&self,
checksum: &str,
cancellable: Option<&P>
) -> Result<(FileInfo, Variant), Error>
Query metadata for a content object.
This is similar to [load_file], but is more efficient if reading the file content is not needed.
sourcepub fn write_content<P: IsA<InputStream>, Q: IsA<Cancellable>>(
&self,
expected_checksum: Option<&str>,
object_input: &P,
length: u64,
cancellable: Option<&Q>
) -> Result<Checksum, Error>
pub fn write_content<P: IsA<InputStream>, Q: IsA<Cancellable>>(
&self,
expected_checksum: Option<&str>,
object_input: &P,
length: u64,
cancellable: Option<&Q>
) -> Result<Checksum, Error>
Write a content object from provided input.
sourcepub fn write_metadata<P: IsA<Cancellable>>(
&self,
objtype: ObjectType,
expected_checksum: Option<&str>,
object: &Variant,
cancellable: Option<&P>
) -> Result<Checksum, Error>
pub fn write_metadata<P: IsA<Cancellable>>(
&self,
objtype: ObjectType,
expected_checksum: Option<&str>,
object: &Variant,
cancellable: Option<&P>
) -> Result<Checksum, Error>
Write a metadata object.
sourcepub fn write_content_async<P: IsA<InputStream>, Q: IsA<Cancellable>, R: FnOnce(Result<Checksum, Error>) + Send + 'static>(
&self,
expected_checksum: Option<&str>,
object: &P,
length: u64,
cancellable: Option<&Q>,
callback: R
)
pub fn write_content_async<P: IsA<InputStream>, Q: IsA<Cancellable>, R: FnOnce(Result<Checksum, Error>) + Send + 'static>(
&self,
expected_checksum: Option<&str>,
object: &P,
length: u64,
cancellable: Option<&Q>,
callback: R
)
Asynchronously write a content object.
sourcepub fn write_content_async_future<P: IsA<InputStream> + Clone + 'static>(
&self,
expected_checksum: Option<&str>,
object: &P,
length: u64
) -> Pin<Box<dyn Future<Output = Result<Checksum, Error>> + 'static>>
pub fn write_content_async_future<P: IsA<InputStream> + Clone + 'static>(
&self,
expected_checksum: Option<&str>,
object: &P,
length: u64
) -> Pin<Box<dyn Future<Output = Result<Checksum, Error>> + 'static>>
Asynchronously write a content object.
sourcepub fn write_metadata_async<P: IsA<Cancellable>, Q: FnOnce(Result<Checksum, Error>) + Send + 'static>(
&self,
objtype: ObjectType,
expected_checksum: Option<&str>,
object: &Variant,
cancellable: Option<&P>,
callback: Q
)
pub fn write_metadata_async<P: IsA<Cancellable>, Q: FnOnce(Result<Checksum, Error>) + Send + 'static>(
&self,
objtype: ObjectType,
expected_checksum: Option<&str>,
object: &Variant,
cancellable: Option<&P>,
callback: Q
)
Asynchronously write a metadata object.
sourcepub fn write_metadata_async_future(
&self,
objtype: ObjectType,
expected_checksum: Option<&str>,
object: &Variant
) -> Pin<Box<dyn Future<Output = Result<Checksum, Error>> + 'static>>
pub fn write_metadata_async_future(
&self,
objtype: ObjectType,
expected_checksum: Option<&str>,
object: &Variant
) -> Pin<Box<dyn Future<Output = Result<Checksum, Error>> + 'static>>
Asynchronously write a metadata object.
sourcepub fn read_dirmeta(&self, checksum: &str) -> Result<DirMetaParsed, Error>
pub fn read_dirmeta(&self, checksum: &str) -> Result<DirMetaParsed, Error>
Load and parse directory metadata. In particular, uid/gid/mode are stored in big-endian format; this function converts them to host native endianness.