Struct ostree::RepoCheckoutFilter
source · pub struct RepoCheckoutFilter(_);Expand description
A filter callback to decide which files to checkout from a Repo. The function is called for every directory and file in the dirtree.
Arguments
repo- theRepothat is being checked outpath- the path of the current file, as an absolute path rooted at the commit’s root. The root directory is ‘/’, a subdir would be ‘/subdir’ etc.stat- the metadata of the current file
Return Value
The return value determines whether the current file is checked out or skipped.
Implementations
sourceimpl RepoCheckoutFilter
impl RepoCheckoutFilter
sourcepub fn new<F>(closure: F) -> Option<RepoCheckoutFilter>where
F: Fn(&Repo, &Path, &stat) -> RepoCheckoutFilterResult + 'static,
pub fn new<F>(closure: F) -> Option<RepoCheckoutFilter>where
F: Fn(&Repo, &Path, &stat) -> RepoCheckoutFilterResult + 'static,
Wrap a closure for use as a filter function.
Return Value
The return value is always Some containing the value. It simply comes pre-wrapped for your
convenience.